# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V42
3058
3059
3442
3443
8559
8560
8575
8577
20191
20192
21315
21316
38433
38434
65826
65827
65869
65870
65876
65877
65905
65906
67678
67679
68059
68060
68167
68168
68447
68448
68479
68480
68863
68864
69733
69734
70132
70133
126092
126093
126236
126237
END
