# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToNFCQC'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToNFCQC'}{'missing'} = 'Yes';

return <<'END';
300	304	M
306	30C	M
30F		M
311		M
313	314	M
31B		M
323	328	M
32D	32E	M
330	331	M
338		M
340	341	N
342		M
343	344	N
345		M
374		N
37E		N
387		N
653	655	M
93C		M
958	95F	N
9BE		M
9D7		M
9DC	9DD	N
9DF		N
A33		N
A36		N
A59	A5B	N
A5E		N
B3E		M
B56	B57	M
B5C	B5D	N
BBE		M
BD7		M
C56		M
CC2		M
CD5	CD6	M
D3E		M
D57		M
DCA		M
DCF		M
DDF		M
F43		N
F4D		N
F52		N
F57		N
F5C		N
F69		N
F73		N
F75	F76	N
F78		N
F81		N
F93		N
F9D		N
FA2		N
FA7		N
FAC		N
FB9		N
102E		M
1161	1175	M
11A8	11C2	M
1B35		M
1F71		N
1F73		N
1F75		N
1F77		N
1F79		N
1F7B		N
1F7D		N
1FBB		N
1FBE		N
1FC9		N
1FCB		N
1FD3		N
1FDB		N
1FE3		N
1FEB		N
1FEE	1FEF	N
1FF9		N
1FFB		N
1FFD		N
2000	2001	N
2126		N
212A	212B	N
2329	232A	N
2ADC		N
3099	309A	M
F900	FA0D	N
FA10		N
FA12		N
FA15	FA1E	N
FA20		N
FA22		N
FA25	FA26	N
FA2A	FA6D	N
FA70	FAD9	N
FB1D		N
FB1F		N
FB2A	FB36	N
FB38	FB3C	N
FB3E		N
FB40	FB41	N
FB43	FB44	N
FB46	FB4E	N
110BA		M
11127		M
1133E		M
11357		M
114B0		M
114BA		M
114BD		M
115AF		M
11930		M
1D15E	1D164	N
1D1BB	1D1C0	N
2F800	2FA1D	N
END
