# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V40
178
180
185
186
4969
4978
6618
6619
8304
8305
8308
8314
8320
8330
9312
9321
9332
9341
9352
9361
9450
9451
9461
9470
9471
9472
10102
10111
10112
10121
10122
10131
68160
68164
69216
69225
69714
69723
127232
127243
END
