# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.



# The name this table is to be known by, with the format of the mappings in
# the main body of the table, and what all code points missing from this file
# map to.
$Unicode::UCD::SwashInfo{'ToHst'}{'format'} = 's'; # string
$Unicode::UCD::SwashInfo{'ToHst'}{'missing'} = 'NA';

return <<'END';
1100	115F	L
1160	11A7	V
11A8	11FF	T
A960	A97C	L
AC00		LV
AC01	AC1B	LVT
AC1C		LV
AC1D	AC37	LVT
AC38		LV
AC39	AC53	LVT
AC54		LV
AC55	AC6F	LVT
AC70		LV
AC71	AC8B	LVT
AC8C		LV
AC8D	ACA7	LVT
ACA8		LV
ACA9	ACC3	LVT
ACC4		LV
ACC5	ACDF	LVT
ACE0		LV
ACE1	ACFB	LVT
ACFC		LV
ACFD	AD17	LVT
AD18		LV
AD19	AD33	LVT
AD34		LV
AD35	AD4F	LVT
AD50		LV
AD51	AD6B	LVT
AD6C		LV
AD6D	AD87	LVT
AD88		LV
AD89	ADA3	LVT
ADA4		LV
ADA5	ADBF	LVT
ADC0		LV
ADC1	ADDB	LVT
ADDC		LV
ADDD	ADF7	LVT
ADF8		LV
ADF9	AE13	LVT
AE14		LV
AE15	AE2F	LVT
AE30		LV
AE31	AE4B	LVT
AE4C		LV
AE4D	AE67	LVT
AE68		LV
AE69	AE83	LVT
AE84		LV
AE85	AE9F	LVT
AEA0		LV
AEA1	AEBB	LVT
AEBC		LV
AEBD	AED7	LVT
AED8		LV
AED9	AEF3	LVT
AEF4		LV
AEF5	AF0F	LVT
AF10		LV
AF11	AF2B	LVT
AF2C		LV
AF2D	AF47	LVT
AF48		LV
AF49	AF63	LVT
AF64		LV
AF65	AF7F	LVT
AF80		LV
AF81	AF9B	LVT
AF9C		LV
AF9D	AFB7	LVT
AFB8		LV
AFB9	AFD3	LVT
AFD4		LV
AFD5	AFEF	LVT
AFF0		LV
AFF1	B00B	LVT
B00C		LV
B00D	B027	LVT
B028		LV
B029	B043	LVT
B044		LV
B045	B05F	LVT
B060		LV
B061	B07B	LVT
B07C		LV
B07D	B097	LVT
B098		LV
B099	B0B3	LVT
B0B4		LV
B0B5	B0CF	LVT
B0D0		LV
B0D1	B0EB	LVT
B0EC		LV
B0ED	B107	LVT
B108		LV
B109	B123	LVT
B124		LV
B125	B13F	LVT
B140		LV
B141	B15B	LVT
B15C		LV
B15D	B177	LVT
B178		LV
B179	B193	LVT
B194		LV
B195	B1AF	LVT
B1B0		LV
B1B1	B1CB	LVT
B1CC		LV
B1CD	B1E7	LVT
B1E8		LV
B1E9	B203	LVT
B204		LV
B205	B21F	LVT
B220		LV
B221	B23B	LVT
B23C		LV
B23D	B257	LVT
B258		LV
B259	B273	LVT
B274		LV
B275	B28F	LVT
B290		LV
B291	B2AB	LVT
B2AC		LV
B2AD	B2C7	LVT
B2C8		LV
B2C9	B2E3	LVT
B2E4		LV
B2E5	B2FF	LVT
B300		LV
B301	B31B	LVT
B31C		LV
B31D	B337	LVT
B338		LV
B339	B353	LVT
B354		LV
B355	B36F	LVT
B370		LV
B371	B38B	LVT
B38C		LV
B38D	B3A7	LVT
B3A8		LV
B3A9	B3C3	LVT
B3C4		LV
B3C5	B3DF	LVT
B3E0		LV
B3E1	B3FB	LVT
B3FC		LV
B3FD	B417	LVT
B418		LV
B419	B433	LVT
B434		LV
B435	B44F	LVT
B450		LV
B451	B46B	LVT
B46C		LV
B46D	B487	LVT
B488		LV
B489	B4A3	LVT
B4A4		LV
B4A5	B4BF	LVT
B4C0		LV
B4C1	B4DB	LVT
B4DC		LV
B4DD	B4F7	LVT
B4F8		LV
B4F9	B513	LVT
B514		LV
B515	B52F	LVT
B530		LV
B531	B54B	LVT
B54C		LV
B54D	B567	LVT
B568		LV
B569	B583	LVT
B584		LV
B585	B59F	LVT
B5A0		LV
B5A1	B5BB	LVT
B5BC		LV
B5BD	B5D7	LVT
B5D8		LV
B5D9	B5F3	LVT
B5F4		LV
B5F5	B60F	LVT
B610		LV
B611	B62B	LVT
B62C		LV
B62D	B647	LVT
B648		LV
B649	B663	LVT
B664		LV
B665	B67F	LVT
B680		LV
B681	B69B	LVT
B69C		LV
B69D	B6B7	LVT
B6B8		LV
B6B9	B6D3	LVT
B6D4		LV
B6D5	B6EF	LVT
B6F0		LV
B6F1	B70B	LVT
B70C		LV
B70D	B727	LVT
B728		LV
B729	B743	LVT
B744		LV
B745	B75F	LVT
B760		LV
B761	B77B	LVT
B77C		LV
B77D	B797	LVT
B798		LV
B799	B7B3	LVT
B7B4		LV
B7B5	B7CF	LVT
B7D0		LV
B7D1	B7EB	LVT
B7EC		LV
B7ED	B807	LVT
B808		LV
B809	B823	LVT
B824		LV
B825	B83F	LVT
B840		LV
B841	B85B	LVT
B85C		LV
B85D	B877	LVT
B878		LV
B879	B893	LVT
B894		LV
B895	B8AF	LVT
B8B0		LV
B8B1	B8CB	LVT
B8CC		LV
B8CD	B8E7	LVT
B8E8		LV
B8E9	B903	LVT
B904		LV
B905	B91F	LVT
B920		LV
B921	B93B	LVT
B93C		LV
B93D	B957	LVT
B958		LV
B959	B973	LVT
B974		LV
B975	B98F	LVT
B990		LV
B991	B9AB	LVT
B9AC		LV
B9AD	B9C7	LVT
B9C8		LV
B9C9	B9E3	LVT
B9E4		LV
B9E5	B9FF	LVT
BA00		LV
BA01	BA1B	LVT
BA1C		LV
BA1D	BA37	LVT
BA38		LV
BA39	BA53	LVT
BA54		LV
BA55	BA6F	LVT
BA70		LV
BA71	BA8B	LVT
BA8C		LV
BA8D	BAA7	LVT
BAA8		LV
BAA9	BAC3	LVT
BAC4		LV
BAC5	BADF	LVT
BAE0		LV
BAE1	BAFB	LVT
BAFC		LV
BAFD	BB17	LVT
BB18		LV
BB19	BB33	LVT
BB34		LV
BB35	BB4F	LVT
BB50		LV
BB51	BB6B	LVT
BB6C		LV
BB6D	BB87	LVT
BB88		LV
BB89	BBA3	LVT
BBA4		LV
BBA5	BBBF	LVT
BBC0		LV
BBC1	BBDB	LVT
BBDC		LV
BBDD	BBF7	LVT
BBF8		LV
BBF9	BC13	LVT
BC14		LV
BC15	BC2F	LVT
BC30		LV
BC31	BC4B	LVT
BC4C		LV
BC4D	BC67	LVT
BC68		LV
BC69	BC83	LVT
BC84		LV
BC85	BC9F	LVT
BCA0		LV
BCA1	BCBB	LVT
BCBC		LV
BCBD	BCD7	LVT
BCD8		LV
BCD9	BCF3	LVT
BCF4		LV
BCF5	BD0F	LVT
BD10		LV
BD11	BD2B	LVT
BD2C		LV
BD2D	BD47	LVT
BD48		LV
BD49	BD63	LVT
BD64		LV
BD65	BD7F	LVT
BD80		LV
BD81	BD9B	LVT
BD9C		LV
BD9D	BDB7	LVT
BDB8		LV
BDB9	BDD3	LVT
BDD4		LV
BDD5	BDEF	LVT
BDF0		LV
BDF1	BE0B	LVT
BE0C		LV
BE0D	BE27	LVT
BE28		LV
BE29	BE43	LVT
BE44		LV
BE45	BE5F	LVT
BE60		LV
BE61	BE7B	LVT
BE7C		LV
BE7D	BE97	LVT
BE98		LV
BE99	BEB3	LVT
BEB4		LV
BEB5	BECF	LVT
BED0		LV
BED1	BEEB	LVT
BEEC		LV
BEED	BF07	LVT
BF08		LV
BF09	BF23	LVT
BF24		LV
BF25	BF3F	LVT
BF40		LV
BF41	BF5B	LVT
BF5C		LV
BF5D	BF77	LVT
BF78		LV
BF79	BF93	LVT
BF94		LV
BF95	BFAF	LVT
BFB0		LV
BFB1	BFCB	LVT
BFCC		LV
BFCD	BFE7	LVT
BFE8		LV
BFE9	C003	LVT
C004		LV
C005	C01F	LVT
C020		LV
C021	C03B	LVT
C03C		LV
C03D	C057	LVT
C058		LV
C059	C073	LVT
C074		LV
C075	C08F	LVT
C090		LV
C091	C0AB	LVT
C0AC		LV
C0AD	C0C7	LVT
C0C8		LV
C0C9	C0E3	LVT
C0E4		LV
C0E5	C0FF	LVT
C100		LV
C101	C11B	LVT
C11C		LV
C11D	C137	LVT
C138		LV
C139	C153	LVT
C154		LV
C155	C16F	LVT
C170		LV
C171	C18B	LVT
C18C		LV
C18D	C1A7	LVT
C1A8		LV
C1A9	C1C3	LVT
C1C4		LV
C1C5	C1DF	LVT
C1E0		LV
C1E1	C1FB	LVT
C1FC		LV
C1FD	C217	LVT
C218		LV
C219	C233	LVT
C234		LV
C235	C24F	LVT
C250		LV
C251	C26B	LVT
C26C		LV
C26D	C287	LVT
C288		LV
C289	C2A3	LVT
C2A4		LV
C2A5	C2BF	LVT
C2C0		LV
C2C1	C2DB	LVT
C2DC		LV
C2DD	C2F7	LVT
C2F8		LV
C2F9	C313	LVT
C314		LV
C315	C32F	LVT
C330		LV
C331	C34B	LVT
C34C		LV
C34D	C367	LVT
C368		LV
C369	C383	LVT
C384		LV
C385	C39F	LVT
C3A0		LV
C3A1	C3BB	LVT
C3BC		LV
C3BD	C3D7	LVT
C3D8		LV
C3D9	C3F3	LVT
C3F4		LV
C3F5	C40F	LVT
C410		LV
C411	C42B	LVT
C42C		LV
C42D	C447	LVT
C448		LV
C449	C463	LVT
C464		LV
C465	C47F	LVT
C480		LV
C481	C49B	LVT
C49C		LV
C49D	C4B7	LVT
C4B8		LV
C4B9	C4D3	LVT
C4D4		LV
C4D5	C4EF	LVT
C4F0		LV
C4F1	C50B	LVT
C50C		LV
C50D	C527	LVT
C528		LV
C529	C543	LVT
C544		LV
C545	C55F	LVT
C560		LV
C561	C57B	LVT
C57C		LV
C57D	C597	LVT
C598		LV
C599	C5B3	LVT
C5B4		LV
C5B5	C5CF	LVT
C5D0		LV
C5D1	C5EB	LVT
C5EC		LV
C5ED	C607	LVT
C608		LV
C609	C623	LVT
C624		LV
C625	C63F	LVT
C640		LV
C641	C65B	LVT
C65C		LV
C65D	C677	LVT
C678		LV
C679	C693	LVT
C694		LV
C695	C6AF	LVT
C6B0		LV
C6B1	C6CB	LVT
C6CC		LV
C6CD	C6E7	LVT
C6E8		LV
C6E9	C703	LVT
C704		LV
C705	C71F	LVT
C720		LV
C721	C73B	LVT
C73C		LV
C73D	C757	LVT
C758		LV
C759	C773	LVT
C774		LV
C775	C78F	LVT
C790		LV
C791	C7AB	LVT
C7AC		LV
C7AD	C7C7	LVT
C7C8		LV
C7C9	C7E3	LVT
C7E4		LV
C7E5	C7FF	LVT
C800		LV
C801	C81B	LVT
C81C		LV
C81D	C837	LVT
C838		LV
C839	C853	LVT
C854		LV
C855	C86F	LVT
C870		LV
C871	C88B	LVT
C88C		LV
C88D	C8A7	LVT
C8A8		LV
C8A9	C8C3	LVT
C8C4		LV
C8C5	C8DF	LVT
C8E0		LV
C8E1	C8FB	LVT
C8FC		LV
C8FD	C917	LVT
C918		LV
C919	C933	LVT
C934		LV
C935	C94F	LVT
C950		LV
C951	C96B	LVT
C96C		LV
C96D	C987	LVT
C988		LV
C989	C9A3	LVT
C9A4		LV
C9A5	C9BF	LVT
C9C0		LV
C9C1	C9DB	LVT
C9DC		LV
C9DD	C9F7	LVT
C9F8		LV
C9F9	CA13	LVT
CA14		LV
CA15	CA2F	LVT
CA30		LV
CA31	CA4B	LVT
CA4C		LV
CA4D	CA67	LVT
CA68		LV
CA69	CA83	LVT
CA84		LV
CA85	CA9F	LVT
CAA0		LV
CAA1	CABB	LVT
CABC		LV
CABD	CAD7	LVT
CAD8		LV
CAD9	CAF3	LVT
CAF4		LV
CAF5	CB0F	LVT
CB10		LV
CB11	CB2B	LVT
CB2C		LV
CB2D	CB47	LVT
CB48		LV
CB49	CB63	LVT
CB64		LV
CB65	CB7F	LVT
CB80		LV
CB81	CB9B	LVT
CB9C		LV
CB9D	CBB7	LVT
CBB8		LV
CBB9	CBD3	LVT
CBD4		LV
CBD5	CBEF	LVT
CBF0		LV
CBF1	CC0B	LVT
CC0C		LV
CC0D	CC27	LVT
CC28		LV
CC29	CC43	LVT
CC44		LV
CC45	CC5F	LVT
CC60		LV
CC61	CC7B	LVT
CC7C		LV
CC7D	CC97	LVT
CC98		LV
CC99	CCB3	LVT
CCB4		LV
CCB5	CCCF	LVT
CCD0		LV
CCD1	CCEB	LVT
CCEC		LV
CCED	CD07	LVT
CD08		LV
CD09	CD23	LVT
CD24		LV
CD25	CD3F	LVT
CD40		LV
CD41	CD5B	LVT
CD5C		LV
CD5D	CD77	LVT
CD78		LV
CD79	CD93	LVT
CD94		LV
CD95	CDAF	LVT
CDB0		LV
CDB1	CDCB	LVT
CDCC		LV
CDCD	CDE7	LVT
CDE8		LV
CDE9	CE03	LVT
CE04		LV
CE05	CE1F	LVT
CE20		LV
CE21	CE3B	LVT
CE3C		LV
CE3D	CE57	LVT
CE58		LV
CE59	CE73	LVT
CE74		LV
CE75	CE8F	LVT
CE90		LV
CE91	CEAB	LVT
CEAC		LV
CEAD	CEC7	LVT
CEC8		LV
CEC9	CEE3	LVT
CEE4		LV
CEE5	CEFF	LVT
CF00		LV
CF01	CF1B	LVT
CF1C		LV
CF1D	CF37	LVT
CF38		LV
CF39	CF53	LVT
CF54		LV
CF55	CF6F	LVT
CF70		LV
CF71	CF8B	LVT
CF8C		LV
CF8D	CFA7	LVT
CFA8		LV
CFA9	CFC3	LVT
CFC4		LV
CFC5	CFDF	LVT
CFE0		LV
CFE1	CFFB	LVT
CFFC		LV
CFFD	D017	LVT
D018		LV
D019	D033	LVT
D034		LV
D035	D04F	LVT
D050		LV
D051	D06B	LVT
D06C		LV
D06D	D087	LVT
D088		LV
D089	D0A3	LVT
D0A4		LV
D0A5	D0BF	LVT
D0C0		LV
D0C1	D0DB	LVT
D0DC		LV
D0DD	D0F7	LVT
D0F8		LV
D0F9	D113	LVT
D114		LV
D115	D12F	LVT
D130		LV
D131	D14B	LVT
D14C		LV
D14D	D167	LVT
D168		LV
D169	D183	LVT
D184		LV
D185	D19F	LVT
D1A0		LV
D1A1	D1BB	LVT
D1BC		LV
D1BD	D1D7	LVT
D1D8		LV
D1D9	D1F3	LVT
D1F4		LV
D1F5	D20F	LVT
D210		LV
D211	D22B	LVT
D22C		LV
D22D	D247	LVT
D248		LV
D249	D263	LVT
D264		LV
D265	D27F	LVT
D280		LV
D281	D29B	LVT
D29C		LV
D29D	D2B7	LVT
D2B8		LV
D2B9	D2D3	LVT
D2D4		LV
D2D5	D2EF	LVT
D2F0		LV
D2F1	D30B	LVT
D30C		LV
D30D	D327	LVT
D328		LV
D329	D343	LVT
D344		LV
D345	D35F	LVT
D360		LV
D361	D37B	LVT
D37C		LV
D37D	D397	LVT
D398		LV
D399	D3B3	LVT
D3B4		LV
D3B5	D3CF	LVT
D3D0		LV
D3D1	D3EB	LVT
D3EC		LV
D3ED	D407	LVT
D408		LV
D409	D423	LVT
D424		LV
D425	D43F	LVT
D440		LV
D441	D45B	LVT
D45C		LV
D45D	D477	LVT
D478		LV
D479	D493	LVT
D494		LV
D495	D4AF	LVT
D4B0		LV
D4B1	D4CB	LVT
D4CC		LV
D4CD	D4E7	LVT
D4E8		LV
D4E9	D503	LVT
D504		LV
D505	D51F	LVT
D520		LV
D521	D53B	LVT
D53C		LV
D53D	D557	LVT
D558		LV
D559	D573	LVT
D574		LV
D575	D58F	LVT
D590		LV
D591	D5AB	LVT
D5AC		LV
D5AD	D5C7	LVT
D5C8		LV
D5C9	D5E3	LVT
D5E4		LV
D5E5	D5FF	LVT
D600		LV
D601	D61B	LVT
D61C		LV
D61D	D637	LVT
D638		LV
D639	D653	LVT
D654		LV
D655	D66F	LVT
D670		LV
D671	D68B	LVT
D68C		LV
D68D	D6A7	LVT
D6A8		LV
D6A9	D6C3	LVT
D6C4		LV
D6C5	D6DF	LVT
D6E0		LV
D6E1	D6FB	LVT
D6FC		LV
D6FD	D717	LVT
D718		LV
D719	D733	LVT
D734		LV
D735	D74F	LVT
D750		LV
D751	D76B	LVT
D76C		LV
D76D	D787	LVT
D788		LV
D789	D7A3	LVT
D7B0	D7C6	V
D7CB	D7FB	T
END
