# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V34
12289
12292
12296
12306
12307
12320
12336
12342
12343
12344
12348
12350
12353
12439
12441
12449
12539
12541
65093
65095
65377
65382
65392
65393
65438
65440
110593
110880
110898
110899
110928
110931
127488
127489
END
