# !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
# This file is machine-generated by lib/unicore/mktables from the Unicode
# database, Version 15.0.0.  Any changes made here will be lost!

# !!!!!!!   INTERNAL PERL USE ONLY   !!!!!!!
# This file is for internal use by core Perl only.  The format and even the
# name or existence of this file are subject to change without notice.  Don't
# use it directly.  Use Unicode::UCD to access the Unicode character data
# base.


return <<'END';
V30
12337
12342
12443
12445
12448
12539
12540
12544
12784
12800
13008
13055
13056
13144
65382
65438
110576
110580
110581
110588
110589
110591
110592
110593
110880
110883
110933
110934
110948
110952
END
